@@ -182,7 +182,7 @@ async def _async_autocorrect(
 
         _display_result(corrected_text, original_text, elapsed, simple_output=general_cfg.quiet)
 
-    except Exception as e:  # noqa: BLE001
+    except Exception as e:
         if general_cfg.quiet:
             print(f"❌ {e}")
         else:
@@ -213,6 +213,7 @@ def autocorrect(
     # OpenAI
     llm_openai_model: str = opts.LLM_OPENAI_MODEL,
     openai_api_key: str | None = opts.OPENAI_API_KEY,
+    openai_base_url: str | None = opts.OPENAI_BASE_URL,
     # Gemini
     llm_gemini_model: str = opts.LLM_GEMINI_MODEL,
     gemini_api_key: str | None = opts.GEMINI_API_KEY,
@@ -235,6 +236,7 @@ def autocorrect(
     openai_llm_cfg = config.OpenAILLM(
         llm_openai_model=llm_openai_model,
         openai_api_key=openai_api_key,
+        openai_base_url=openai_base_url,
     )
     gemini_llm_cfg = config.GeminiLLM(
         llm_gemini_model=llm_gemini_model,
