@@ -59,6 +59,12 @@ OPENAI_API_KEY: str | None = typer.Option(
     envvar="OPENAI_API_KEY",
     rich_help_panel="LLM Configuration: OpenAI",
 )
+OPENAI_BASE_URL: str | None = typer.Option(
+    None,
+    "--openai-base-url",
+    help="Custom base URL for OpenAI-compatible API (e.g., for llama-server: http://localhost:8080/v1).",
+    rich_help_panel="LLM Configuration: OpenAI",
+)
 # Gemini
 LLM_GEMINI_MODEL: str = typer.Option(
     "gemini-2.5-flash",
@@ -310,3 +316,29 @@ SAVE_FILE: Path | None = typer.Option(
     help="Save TTS response audio to WAV file.",
     rich_help_panel="General Options",
 )
+TRANSCRIPTION_LOG: Path | None = typer.Option(
+    None,
+    "--transcription-log",
+    help="Path to log transcription results with timestamps, hostname, model, and raw output.",
+    rich_help_panel="General Options",
+)
+
+# --- Transcribe Specific Options ---
+FROM_FILE: Path | None = typer.Option(
+    None,
+    "--from-file",
+    help="Transcribe audio from a saved WAV file instead of recording.",
+    rich_help_panel="Audio Recovery",
+)
+LAST_RECORDING: int = typer.Option(
+    0,
+    "--last-recording",
+    help="Transcribe a saved recording. Use 1 for most recent, 2 for second-to-last, etc. Use 0 to disable (default).",
+    rich_help_panel="Audio Recovery",
+)
+SAVE_RECORDING: bool = typer.Option(
+    True,  # noqa: FBT003
+    "--save-recording/--no-save-recording",
+    help="Save the audio recording to disk for recovery.",
+    rich_help_panel="Audio Recovery",
+)
