@@ -26,10 +26,20 @@ def _openai_llm_model(openai_cfg: config.OpenAILLM) -> OpenAIModel:
     from pydantic_ai.models.openai import OpenAIModel  # noqa: PLC0415
     from pydantic_ai.providers.openai import OpenAIProvider  # noqa: PLC0415
 
-    if not openai_cfg.openai_api_key:
-        msg = "OpenAI API key is not set."
-        raise ValueError(msg)
-    provider = OpenAIProvider(api_key=openai_cfg.openai_api_key)
+    # For custom base URLs (like llama-server), API key might not be required
+    if openai_cfg.openai_base_url:
+        # Custom endpoint - API key is optional
+        provider = OpenAIProvider(
+            api_key=openai_cfg.openai_api_key or "dummy",
+            base_url=openai_cfg.openai_base_url,
+        )
+    else:
+        # Standard OpenAI - API key is required
+        if not openai_cfg.openai_api_key:
+            msg = "OpenAI API key is not set."
+            raise ValueError(msg)
+        provider = OpenAIProvider(api_key=openai_cfg.openai_api_key)
+
     model_name = openai_cfg.llm_openai_model
     return OpenAIModel(model_name=model_name, provider=provider)
 
@@ -187,12 +197,12 @@ async def process_and_update_clipboard(
     instruction: str,
     clipboard: bool,
     quiet: bool,
-    live: Live,
-) -> None:
+    live: Live | None,
+) -> str | None:
     """Processes the text with the LLM, updates the clipboard, and displays the result."""
     user_input = INPUT_TEMPLATE.format(original_text=original_text, instruction=instruction)
 
-    await get_llm_response(
+    return await get_llm_response(
         system_prompt=system_prompt,
         agent_instructions=agent_instructions,
         user_input=user_input,
@@ -205,5 +215,5 @@ async def process_and_update_clipboard(
         clipboard=clipboard,
         live=live,
         show_output=True,
-        exit_on_error=True,
+        exit_on_error=False,  # Don't exit the server on LLM errors
     )
