@@ -22,7 +22,11 @@ def test_create_llm_agent_openai_no_key():
         llm_ollama_model="test-model",
         llm_ollama_host="http://mockhost:1234",
     )
-    openai_llm_cfg = config.OpenAILLM(llm_openai_model="gpt-4o-mini", openai_api_key=None)
+    openai_llm_cfg = config.OpenAILLM(
+        llm_openai_model="gpt-4o-mini",
+        openai_api_key=None,
+        openai_base_url=None,
+    )
     gemini_llm_cfg = config.GeminiLLM(
         llm_gemini_model="gemini-1.5-flash",
         gemini_api_key="test-key",
@@ -44,7 +48,11 @@ def test_create_llm_agent(monkeypatch: pytest.MonkeyPatch) -> None:
         llm_ollama_model="test-model",
         llm_ollama_host="http://mockhost:1234",
     )
-    openai_llm_cfg = config.OpenAILLM(llm_openai_model="gpt-4o-mini", openai_api_key=None)
+    openai_llm_cfg = config.OpenAILLM(
+        llm_openai_model="gpt-4o-mini",
+        openai_api_key=None,
+        openai_base_url=None,
+    )
     gemini_llm_cfg = config.GeminiLLM(
         llm_gemini_model="gemini-1.5-flash",
         gemini_api_key="test-key",
@@ -69,7 +77,11 @@ async def test_get_llm_response(mock_create_llm_agent: MagicMock) -> None:
         tts_provider="local",
     )
     ollama_cfg = config.Ollama(llm_ollama_model="test", llm_ollama_host="test")
-    openai_llm_cfg = config.OpenAILLM(llm_openai_model="gpt-4o-mini", openai_api_key=None)
+    openai_llm_cfg = config.OpenAILLM(
+        llm_openai_model="gpt-4o-mini",
+        openai_api_key=None,
+        openai_base_url=None,
+    )
     gemini_llm_cfg = config.GeminiLLM(
         llm_gemini_model="gemini-1.5-flash",
         gemini_api_key="test-key",
@@ -106,7 +118,11 @@ async def test_get_llm_response_error(mock_create_llm_agent: MagicMock) -> None:
         tts_provider="local",
     )
     ollama_cfg = config.Ollama(llm_ollama_model="test", llm_ollama_host="test")
-    openai_llm_cfg = config.OpenAILLM(llm_openai_model="gpt-4o-mini", openai_api_key=None)
+    openai_llm_cfg = config.OpenAILLM(
+        llm_openai_model="gpt-4o-mini",
+        openai_api_key=None,
+        openai_base_url=None,
+    )
     gemini_llm_cfg = config.GeminiLLM(
         llm_gemini_model="gemini-1.5-flash",
         gemini_api_key="test-key",
@@ -143,7 +159,11 @@ async def test_get_llm_response_error_exit(mock_create_llm_agent: MagicMock):
         tts_provider="local",
     )
     ollama_cfg = config.Ollama(llm_ollama_model="test", llm_ollama_host="test")
-    openai_llm_cfg = config.OpenAILLM(llm_openai_model="gpt-4o-mini", openai_api_key=None)
+    openai_llm_cfg = config.OpenAILLM(
+        llm_openai_model="gpt-4o-mini",
+        openai_api_key=None,
+        openai_base_url=None,
+    )
     gemini_llm_cfg = config.GeminiLLM(
         llm_gemini_model="gemini-1.5-flash",
         gemini_api_key="test-key",
@@ -178,7 +198,11 @@ def test_process_and_update_clipboard(
         tts_provider="local",
     )
     ollama_cfg = config.Ollama(llm_ollama_model="test", llm_ollama_host="test")
-    openai_llm_cfg = config.OpenAILLM(llm_openai_model="gpt-4o-mini", openai_api_key=None)
+    openai_llm_cfg = config.OpenAILLM(
+        llm_openai_model="gpt-4o-mini",
+        openai_api_key=None,
+        openai_base_url=None,
+    )
     gemini_llm_cfg = config.GeminiLLM(
         llm_gemini_model="gemini-1.5-flash",
         gemini_api_key="test-key",
@@ -208,4 +232,4 @@ def test_process_and_update_clipboard(
     assert call_args.kwargs["quiet"] is True
     assert call_args.kwargs["live"] is mock_live
     assert call_args.kwargs["show_output"] is True
-    assert call_args.kwargs["exit_on_error"] is True
+    assert call_args.kwargs["exit_on_error"] is False
